Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(613)

Unified Diff: chrome/browser/chromeos/arc/arc_migration_constants.h

Issue 2968643002: Update minimum space for migration to 50MB (Closed)
Patch Set: Update minimum space for migration to 50MB Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/arc/arc_migration_constants.h
diff --git a/chrome/browser/chromeos/arc/arc_migration_constants.h b/chrome/browser/chromeos/arc/arc_migration_constants.h
index 95b02305c75732694e39fdfeca75669e399edfd1..b397bf63553e734905b8ce78213e9e835d2800e4 100644
--- a/chrome/browser/chromeos/arc/arc_migration_constants.h
+++ b/chrome/browser/chromeos/arc/arc_migration_constants.h
@@ -10,8 +10,8 @@ namespace arc {
// The minimum battery level to start the migration.
constexpr double kMigrationMinimumBatteryPercent = 30;
-// The minimum size of available space to start the migration. (10MB)
-constexpr int64_t kMigrationMinimumAvailableStorage = 10LL * 1024 * 1024;
+// The minimum size of available space to start the migration. (50MB)
+constexpr int64_t kMigrationMinimumAvailableStorage = 50LL * 1024 * 1024;
} // namespace arc
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698